











































import requests
import concurrent.futures
import time
import urllib.parse
import os

def read_idcards(file_path):
    """
    读取身份证号列表
    """
    if not os.path.exists(file_path):
        raise FileNotFoundError(f"文件 {file_path} 不存在。")
    with open(file_path, 'r', encoding='utf-8') as f:
        idcards = [line.strip() for line in f if line.strip()]
    return idcards

def build_url(name, idcard, mobileno):
    """
    构建请求URL
    """
    base_url = "https://nbapp.ihuiyin.com/esign/RequestIDCode"  # 替换为实际的API端点
    # 对参数进行URL编码
    params = {
        "name": urllib.parse.quote(name),
        "idcardno": idcard,
        "mobileno": mobileno
    }
    query_string = urllib.parse.urlencode(params)
    url = f"{base_url}?{query_string}"
    return url

def verify_operator_three_elements(name, idcard, mobileno):
    """
    核验运营商三要素是否一致
    """
    url = build_url(name, idcard, mobileno)
    headers = {
        "Content-Type": "application/json"
    }
    
    try:
        response = requests.get(url, headers=headers, timeout=20)
        response.raise_for_status()
        data = response.json()
        
        # 根据实际API返回的结构调整
        # 假设返回中有一个字段 'type' 表示是否一致
        # 'type' 为0表示一致，为1表示不一致
        Type_field = data.get('Type')
        if Type_field == 0:
            return True, data
        elif Type_field == 1:
            return False, data
        else:
            print(f"未知的 Type 值: {type_field}")
            return False, data
    except requests.RequestException as e:
        print(f"请求错误: {e}")
        return False, None
    except ValueError:
        print("响应解析错误")
        return False, None

def main():
    # 用户输入
    name = input("请输入姓名: ").strip()
    mobileno = input("请输入手机号: ").strip()
    
    # 读取身份证号
    idcards = read_idcards('提取.txt')
    if not idcards:
        print("身份证号列表为空。")
        return
    
    # 记录开始时间
    start_time = time.time()
    
    # 使用 ThreadPoolExecutor 进行多线程处理
    with concurrent.futures.ThreadPoolExecutor(max_workers=1) as executor:
        # 创建一个未来对象列表
        futures = [executor.submit(verify_operator_three_elements, name, idcard, mobileno) for idcard in idcards]
        
        for future in concurrent.futures.as_completed(futures):
            result, response_data = future.result()
            # 获取对应的身份证号
            idcard = idcards.pop(0)  # 假设列表顺序对应
            if result:
                # 找到第一个三要素一致的结果
                elapsed_time = time.time() - start_time
                print(f"✅{name}-{idcard}-{mobileno}-三要素一致✅")
                print(f"响应内容: {response_data}")
                return
            else:
                # 输出不一致的结果
                elapsed_time = time.time() - start_time
                print(f"{name}-{idcard}-{mobileno}-三要素不一致")
                print(f"响应内容: {response_data}")
    
    # 如果所有验证完成都没有找到一致的结果
    elapsed_time = time.time() - start_time
    print(f"所有验证完成，未找到三要素一致的结果，耗时: {elapsed_time:.2f} 秒")

if __name__ == "__main__":
    main()
